@@ -20,7 +20,9 @@ class MVPolyCube(mvpoly.base.MVPoly) :
     the coefficient array set to the optional *coef*
     argument, a :class:`numpy.ndarray`.
     """
-    def __init__(self, coef = [], **kwd):
+    def __init__(self, coef = None, **kwd):
+        if coef is None :
+            coef = []
         super(MVPolyCube, self).__init__(**kwd)
         self._coef = np.array(coef, dtype = self.dtype)
 
